==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/BingMapsMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { BingMapsMapImageryDescription } from "./BingMapsMapImageryDescription";
/**
 * @hidden
 */
var BingMapsMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(BingMapsMapImageryDescriptionMetadata, _super);
    function BingMapsMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BingMapsMapImageryDescriptionMetadata.b = function (a) {
        if (BingMapsMapImageryDescriptionMetadata.a == null) {
            BingMapsMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BingMapsMapImageryDescriptionMetadata.c(BingMapsMapImageryDescriptionMetadata.a);
        }
        if (a.g(BingMapsMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.s(BingMapsMapImageryDescriptionMetadata.a);
    };
    BingMapsMapImageryDescriptionMetadata.c = function (a) {
        GeographicMapImageryDescriptionMetadata.c(a);
        a.item("IsInitialized", "Boolean");
        a.item("IsDeferredLoad", "Boolean");
        a.item("TilePath", "String");
        a.item("ActualTilePath", "String");
        a.item("SubDomains", "Collection:String:SubDomainsCollection:String");
        a.item("ActualSubDomains", "Collection:String:SubDomainsCollection:String");
        a.item("BingImageryRestUri", "String");
        a.item("ActualBingImageryRestUri", "String");
        a.item("CultureName", "String");
        a.item("ApiKey", "String");
        a.item("ImageryStyle", "ExportedType:string:BingMapsImageryStyle");
        a.item("ImageryStyle@names", "Aerial;AerialWithLabels;Road;CanvasDark;CanvasLight;CanvasGray");
    };
    BingMapsMapImageryDescriptionMetadata.d = function (a) {
        BingMapsMapImageryDescriptionMetadata.b(a);
        a.u("BingMapsMapImagery", function () { return new BingMapsMapImageryDescription(); });
        a.t("BingMapsMapImagery", BingMapsMapImageryDescriptionMetadata.a);
    };
    BingMapsMapImageryDescriptionMetadata.$t = markType(BingMapsMapImageryDescriptionMetadata, 'BingMapsMapImageryDescriptionMetadata');
    BingMapsMapImageryDescriptionMetadata.a = null;
    return BingMapsMapImageryDescriptionMetadata;
}(Base));
export { BingMapsMapImageryDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/BingMapsMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { BingMapsMapImageryDescription } from "./BingMapsMapImageryDescription";
/**
 * @hidden
 */
var BingMapsMapImageryDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(BingMapsMapImageryDescriptionMetadata, _super);
    function BingMapsMapImageryDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BingMapsMapImageryDescriptionMetadata.b = function (a) {
        if (BingMapsMapImageryDescriptionMetadata.a == null) {
            BingMapsMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BingMapsMapImageryDescriptionMetadata.c(BingMapsMapImageryDescriptionMetadata.a);
        }
        if (a.j(BingMapsMapImageryDescriptionMetadata.a)) {
            return;
        }
        a.y(BingMapsMapImageryDescriptionMetadata.a);
    };
    BingMapsMapImageryDescriptionMetadata.c = function (a) {
        GeographicMapImageryDescriptionMetadata.c(a);
        a.item("IsInitialized", "Boolean");
        a.item("IsDeferredLoad", "Boolean");
        a.item("TilePath", "String");
        a.item("ActualTilePath", "String");
        a.item("SubDomains", "Collection:String:SubDomainsCollection:String");
        a.item("ActualSubDomains", "Collection:String:SubDomainsCollection:String");
        a.item("BingImageryRestUri", "String");
        a.item("ActualBingImageryRestUri", "String");
        a.item("CultureName", "String");
        a.item("ApiKey", "String");
        a.item("ImageryStyle", "ExportedType:string:BingMapsImageryStyle");
        a.item("ImageryStyle@names", "Aerial;AerialWithLabels;Road;CanvasDark;CanvasLight;CanvasGray");
    };
    BingMapsMapImageryDescriptionMetadata.d = function (a) {
        BingMapsMapImageryDescriptionMetadata.b(a);
        a.aa("BingMapsMapImagery", function () { return new BingMapsMapImageryDescription(); });
        a.z("BingMapsMapImagery", BingMapsMapImageryDescriptionMetadata.a);
    };
    BingMapsMapImageryDescriptionMetadata.$t = markType(BingMapsMapImageryDescriptionMetadata, 'BingMapsMapImageryDescriptionMetadata');
    BingMapsMapImageryDescriptionMetadata.a = null;
    return BingMapsMapImageryDescriptionMetadata;
}(Base));
export { BingMapsMapImageryDescriptionMetadata };
